import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_mylibrary/http/exception/http_error.dart';

mixin BaseViewState{

  /// 防止页面销毁后,异步任务才完成,导致报错
  bool disposed = false;

  /// 当前的页面状态,默认为busy,可在viewModel的构造方法中指定;
  ViewState viewState = ViewState.busy;

  EasyRefreshController _refreshController = EasyRefreshController();

  set refreshController(EasyRefreshController easyRefreshController){
    this._refreshController = easyRefreshController;
  }


  EasyRefreshController get refreshController => _refreshController;

  bool isInit = false;



  ///重新请求当报错时
  void requestWhenError();

  ///---------------------------------------------页面状态------------------------------------------------------

  HttpError httpError;

  bool get isBusy => viewState == ViewState.busy;

  bool get isIdle => viewState == ViewState.idle;

  bool get isError => viewState == ViewState.error;


  ///---------------------------------------------设置页面状态------------------------------------------------------


  void setIdle();

  void setBusy();

  void setError(HttpError httpError);


  HttpError getEmptyDataError(data){
    HttpError httpError = HttpError(HttpErrorType.EmptyDataError, NO_DATA_MSG, logMsg: '空数据: $data');
    return httpError;
  }


  HttpError getParseDataError(Exception e){
    HttpError httpError = HttpError(HttpErrorType.DataError, PARSE_ERROR_MSG, logMsg: '数据解析错误', cause: e);
    return httpError;
  }

  void onError(HttpError httpError) {}



}



/// 页面状态类型
enum ViewState {
  idle,
  busy,
  error
}